@@ -119,7 +119,7 @@ def run_unit_test(unit_test: UnitTests):
 
     if unit_test == UnitTests.MODEL_TEST:
 
-        from qis.data.yf_data import load_etf_data
+        from qis.test_data import load_etf_data
         prices = load_etf_data().dropna()
 
         returns = np.log(prices.divide(prices.shift(1)))
